| Title: | LLM-Based Bayesian Prior Elicitation Wizard |
|---|---|
| Description: | 'Shiny' application for eliciting Bayesian prior distributions using large language models (LLMs). Supports multiple LLM experts, linear opinion pooling, and the Delphi method for iterative consensus. For more details see J. R. Falconer et al. (2022) <doi:10.1287/deca.2022.0451> and D. Selby et al. (2025) <doi:10.1002/sta4.70054>. |
| Authors: | Jeffery A. Kportufe [aut, cre] |
| Maintainer: | Jeffery A. Kportufe <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-29 19:42:09 UTC |
| Source: | https://github.com/cran/ElicitationWizard |
Launches the LLM-based Bayesian prior elicitation wizard.
run_elicitation(...)run_elicitation(...)
... |
Arguments passed to |
No return value, called for side effects. Launches a Shiny application in the user's default web browser or the RStudio View pane.
if (interactive()){ run_elicitation() }if (interactive()){ run_elicitation() }